@@ -1,10 +1,14 @@
+# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,unused-import
 """
 Main interface for budgets service client paginators.
 
 Usage::
 
+    ```python
     import boto3
-    from mypy_boto3.budgets import (
+
+    from mypy_boto3_budgets import BudgetsClient
+    from mypy_boto3_budgets.paginator import (
         DescribeBudgetsPaginator,
         DescribeNotificationsForBudgetPaginator,
         DescribeSubscribersForNotificationPaginator,
@@ -15,10 +19,12 @@ Usage::
     describe_budgets_paginator: DescribeBudgetsPaginator = client.get_paginator("describe_budgets")
     describe_notifications_for_budget_paginator: DescribeNotificationsForBudgetPaginator = client.get_paginator("describe_notifications_for_budget")
     describe_subscribers_for_notification_paginator: DescribeSubscribersForNotificationPaginator = client.get_paginator("describe_subscribers_for_notification")
+    ```
 """
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from typing import Iterator, TYPE_CHECKING
+from typing import Iterator
+
 from botocore.paginate import Paginator as Boto3Paginator
+
 from mypy_boto3_budgets.type_defs import (
     DescribeBudgetsResponseTypeDef,
     DescribeNotificationsForBudgetResponseTypeDef,
@@ -27,7 +33,6 @@ from mypy_boto3_budgets.type_defs import (
     PaginatorConfigTypeDef,
 )
 
-
 __all__ = (
     "DescribeBudgetsPaginator",
     "DescribeNotificationsForBudgetPaginator",
@@ -37,42 +42,42 @@ __all__ = (
 
 class DescribeBudgetsPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeBudgets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/budgets.html#Budgets.Paginator.DescribeBudgets)
+    [Paginator.DescribeBudgets documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.26/reference/services/budgets.html#Budgets.Paginator.DescribeBudgets)
     """
 
     def paginate(
         self, AccountId: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[DescribeBudgetsResponseTypeDef]:
         """
-        [DescribeBudgets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/budgets.html#Budgets.Paginator.DescribeBudgets.paginate)
+        [DescribeBudgets.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.26/reference/services/budgets.html#Budgets.Paginator.DescribeBudgets.paginate)
         """
 
 
 class DescribeNotificationsForBudgetPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeNotificationsForBudget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/budgets.html#Budgets.Paginator.DescribeNotificationsForBudget)
+    [Paginator.DescribeNotificationsForBudget documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.26/reference/services/budgets.html#Budgets.Paginator.DescribeNotificationsForBudget)
     """
 
     def paginate(
         self, AccountId: str, BudgetName: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Iterator[DescribeNotificationsForBudgetResponseTypeDef]:
         """
-        [DescribeNotificationsForBudget.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/budgets.html#Budgets.Paginator.DescribeNotificationsForBudget.paginate)
+        [DescribeNotificationsForBudget.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.26/reference/services/budgets.html#Budgets.Paginator.DescribeNotificationsForBudget.paginate)
         """
 
 
 class DescribeSubscribersForNotificationPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeSubscribersForNotification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/budgets.html#Budgets.Paginator.DescribeSubscribersForNotification)
+    [Paginator.DescribeSubscribersForNotification documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.26/reference/services/budgets.html#Budgets.Paginator.DescribeSubscribersForNotification)
     """
 
     def paginate(
         self,
         AccountId: str,
         BudgetName: str,
-        Notification: NotificationTypeDef,
+        Notification: "NotificationTypeDef",
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[DescribeSubscribersForNotificationResponseTypeDef]:
         """
-        [DescribeSubscribersForNotification.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.13.19/reference/services/budgets.html#Budgets.Paginator.DescribeSubscribersForNotification.paginate)
+        [DescribeSubscribersForNotification.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.26/reference/services/budgets.html#Budgets.Paginator.DescribeSubscribersForNotification.paginate)
         """
