@@ -3,18 +3,21 @@ Main interface for budgets service type definitions.
 
 Usage::
 
-    from mypy_boto3.budgets.type_defs import SpendTypeDef
+    ```python
+    from mypy_boto3_budgets.type_defs import BudgetPerformanceHistoryTypeDef
 
-    data: SpendTypeDef = {...}
+    data: BudgetPerformanceHistoryTypeDef = {...}
+    ```
 """
-from datetime import datetime
 import sys
+from datetime import datetime
 from typing import Dict, List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
 else:
     from typing_extensions import Literal
+
 if sys.version_info >= (3, 8):
     from typing import TypedDict
 else:
@@ -22,31 +25,93 @@ else:
 
 
 __all__ = (
-    "SpendTypeDef",
-    "CalculatedSpendTypeDef",
-    "CostTypesTypeDef",
-    "TimePeriodTypeDef",
+    "BudgetPerformanceHistoryTypeDef",
     "BudgetTypeDef",
     "BudgetedAndActualAmountsTypeDef",
-    "BudgetPerformanceHistoryTypeDef",
+    "CalculatedSpendTypeDef",
+    "CostTypesTypeDef",
+    "NotificationTypeDef",
+    "SpendTypeDef",
+    "SubscriberTypeDef",
+    "TimePeriodTypeDef",
     "DescribeBudgetPerformanceHistoryResponseTypeDef",
     "DescribeBudgetResponseTypeDef",
     "DescribeBudgetsResponseTypeDef",
-    "NotificationTypeDef",
     "DescribeNotificationsForBudgetResponseTypeDef",
-    "SubscriberTypeDef",
     "DescribeSubscribersForNotificationResponseTypeDef",
     "NotificationWithSubscribersTypeDef",
     "PaginatorConfigTypeDef",
 )
 
-SpendTypeDef = TypedDict("SpendTypeDef", {"Amount": str, "Unit": str})
+BudgetPerformanceHistoryTypeDef = TypedDict(
+    "BudgetPerformanceHistoryTypeDef",
+    {
+        "BudgetName": str,
+        "BudgetType": Literal[
+            "USAGE",
+            "COST",
+            "RI_UTILIZATION",
+            "RI_COVERAGE",
+            "SAVINGS_PLANS_UTILIZATION",
+            "SAVINGS_PLANS_COVERAGE",
+        ],
+        "CostFilters": Dict[str, List[str]],
+        "CostTypes": "CostTypesTypeDef",
+        "TimeUnit": Literal["DAILY", "MONTHLY", "QUARTERLY", "ANNUALLY"],
+        "BudgetedAndActualAmountsList": List["BudgetedAndActualAmountsTypeDef"],
+    },
+    total=False,
+)
+
+_RequiredBudgetTypeDef = TypedDict(
+    "_RequiredBudgetTypeDef",
+    {
+        "BudgetName": str,
+        "TimeUnit": Literal["DAILY", "MONTHLY", "QUARTERLY", "ANNUALLY"],
+        "BudgetType": Literal[
+            "USAGE",
+            "COST",
+            "RI_UTILIZATION",
+            "RI_COVERAGE",
+            "SAVINGS_PLANS_UTILIZATION",
+            "SAVINGS_PLANS_COVERAGE",
+        ],
+    },
+)
+_OptionalBudgetTypeDef = TypedDict(
+    "_OptionalBudgetTypeDef",
+    {
+        "BudgetLimit": "SpendTypeDef",
+        "PlannedBudgetLimits": Dict[str, "SpendTypeDef"],
+        "CostFilters": Dict[str, List[str]],
+        "CostTypes": "CostTypesTypeDef",
+        "TimePeriod": "TimePeriodTypeDef",
+        "CalculatedSpend": "CalculatedSpendTypeDef",
+        "LastUpdatedTime": datetime,
+    },
+    total=False,
+)
+
+
+class BudgetTypeDef(_RequiredBudgetTypeDef, _OptionalBudgetTypeDef):
+    pass
+
+
+BudgetedAndActualAmountsTypeDef = TypedDict(
+    "BudgetedAndActualAmountsTypeDef",
+    {
+        "BudgetedAmount": "SpendTypeDef",
+        "ActualAmount": "SpendTypeDef",
+        "TimePeriod": "TimePeriodTypeDef",
+    },
+    total=False,
+)
 
 _RequiredCalculatedSpendTypeDef = TypedDict(
-    "_RequiredCalculatedSpendTypeDef", {"ActualSpend": SpendTypeDef}
+    "_RequiredCalculatedSpendTypeDef", {"ActualSpend": "SpendTypeDef"}
 )
 _OptionalCalculatedSpendTypeDef = TypedDict(
-    "_OptionalCalculatedSpendTypeDef", {"ForecastedSpend": SpendTypeDef}, total=False
+    "_OptionalCalculatedSpendTypeDef", {"ForecastedSpend": "SpendTypeDef"}, total=False
 )
 
 
@@ -72,86 +137,6 @@ CostTypesTypeDef = TypedDict(
     total=False,
 )
 
-TimePeriodTypeDef = TypedDict(
-    "TimePeriodTypeDef", {"Start": datetime, "End": datetime}, total=False
-)
-
-_RequiredBudgetTypeDef = TypedDict(
-    "_RequiredBudgetTypeDef",
-    {
-        "BudgetName": str,
-        "TimeUnit": Literal["DAILY", "MONTHLY", "QUARTERLY", "ANNUALLY"],
-        "BudgetType": Literal[
-            "USAGE",
-            "COST",
-            "RI_UTILIZATION",
-            "RI_COVERAGE",
-            "SAVINGS_PLANS_UTILIZATION",
-            "SAVINGS_PLANS_COVERAGE",
-        ],
-    },
-)
-_OptionalBudgetTypeDef = TypedDict(
-    "_OptionalBudgetTypeDef",
-    {
-        "BudgetLimit": SpendTypeDef,
-        "PlannedBudgetLimits": Dict[str, SpendTypeDef],
-        "CostFilters": Dict[str, List[str]],
-        "CostTypes": CostTypesTypeDef,
-        "TimePeriod": TimePeriodTypeDef,
-        "CalculatedSpend": CalculatedSpendTypeDef,
-        "LastUpdatedTime": datetime,
-    },
-    total=False,
-)
-
-
-class BudgetTypeDef(_RequiredBudgetTypeDef, _OptionalBudgetTypeDef):
-    pass
-
-
-BudgetedAndActualAmountsTypeDef = TypedDict(
-    "BudgetedAndActualAmountsTypeDef",
-    {"BudgetedAmount": SpendTypeDef, "ActualAmount": SpendTypeDef, "TimePeriod": TimePeriodTypeDef},
-    total=False,
-)
-
-BudgetPerformanceHistoryTypeDef = TypedDict(
-    "BudgetPerformanceHistoryTypeDef",
-    {
-        "BudgetName": str,
-        "BudgetType": Literal[
-            "USAGE",
-            "COST",
-            "RI_UTILIZATION",
-            "RI_COVERAGE",
-            "SAVINGS_PLANS_UTILIZATION",
-            "SAVINGS_PLANS_COVERAGE",
-        ],
-        "CostFilters": Dict[str, List[str]],
-        "CostTypes": CostTypesTypeDef,
-        "TimeUnit": Literal["DAILY", "MONTHLY", "QUARTERLY", "ANNUALLY"],
-        "BudgetedAndActualAmountsList": List[BudgetedAndActualAmountsTypeDef],
-    },
-    total=False,
-)
-
-DescribeBudgetPerformanceHistoryResponseTypeDef = TypedDict(
-    "DescribeBudgetPerformanceHistoryResponseTypeDef",
-    {"BudgetPerformanceHistory": BudgetPerformanceHistoryTypeDef, "NextToken": str},
-    total=False,
-)
-
-DescribeBudgetResponseTypeDef = TypedDict(
-    "DescribeBudgetResponseTypeDef", {"Budget": BudgetTypeDef}, total=False
-)
-
-DescribeBudgetsResponseTypeDef = TypedDict(
-    "DescribeBudgetsResponseTypeDef",
-    {"Budgets": List[BudgetTypeDef], "NextToken": str},
-    total=False,
-)
-
 _RequiredNotificationTypeDef = TypedDict(
     "_RequiredNotificationTypeDef",
     {
@@ -174,25 +159,47 @@ class NotificationTypeDef(_RequiredNotificationTypeDef, _OptionalNotificationTyp
     pass
 
 
-DescribeNotificationsForBudgetResponseTypeDef = TypedDict(
-    "DescribeNotificationsForBudgetResponseTypeDef",
-    {"Notifications": List[NotificationTypeDef], "NextToken": str},
-    total=False,
-)
+SpendTypeDef = TypedDict("SpendTypeDef", {"Amount": str, "Unit": str})
 
 SubscriberTypeDef = TypedDict(
     "SubscriberTypeDef", {"SubscriptionType": Literal["SNS", "EMAIL"], "Address": str}
 )
 
+TimePeriodTypeDef = TypedDict(
+    "TimePeriodTypeDef", {"Start": datetime, "End": datetime}, total=False
+)
+
+DescribeBudgetPerformanceHistoryResponseTypeDef = TypedDict(
+    "DescribeBudgetPerformanceHistoryResponseTypeDef",
+    {"BudgetPerformanceHistory": "BudgetPerformanceHistoryTypeDef", "NextToken": str},
+    total=False,
+)
+
+DescribeBudgetResponseTypeDef = TypedDict(
+    "DescribeBudgetResponseTypeDef", {"Budget": "BudgetTypeDef"}, total=False
+)
+
+DescribeBudgetsResponseTypeDef = TypedDict(
+    "DescribeBudgetsResponseTypeDef",
+    {"Budgets": List["BudgetTypeDef"], "NextToken": str},
+    total=False,
+)
+
+DescribeNotificationsForBudgetResponseTypeDef = TypedDict(
+    "DescribeNotificationsForBudgetResponseTypeDef",
+    {"Notifications": List["NotificationTypeDef"], "NextToken": str},
+    total=False,
+)
+
 DescribeSubscribersForNotificationResponseTypeDef = TypedDict(
     "DescribeSubscribersForNotificationResponseTypeDef",
-    {"Subscribers": List[SubscriberTypeDef], "NextToken": str},
+    {"Subscribers": List["SubscriberTypeDef"], "NextToken": str},
     total=False,
 )
 
 NotificationWithSubscribersTypeDef = TypedDict(
     "NotificationWithSubscribersTypeDef",
-    {"Notification": NotificationTypeDef, "Subscribers": List[SubscriberTypeDef]},
+    {"Notification": "NotificationTypeDef", "Subscribers": List["SubscriberTypeDef"]},
 )
 
 PaginatorConfigTypeDef = TypedDict(
